=====================
Simulation Data Files
=====================

.. _inputs_csv:

This section details the CSV files that are used to populate the simulation data.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   commodities
   projections
   technodata
   technodata_timeslices
   commodities_io
   existing_capacity
   agents
   preset_commodity_demands
   correlation_files
